@@ -3,9 +3,12 @@ import torch
 from functools import reduce
 from pathlib import Path
 
-from imagen_pytorch import Imagen
+from imagen_pytorch import ImagenConfig, ElucidatedImagenConfig
 from imagen_pytorch.version import __version__
 
+def exists(val):
+    return val is not None
+
 def safeget(dictionary, keys, default = None):
     return reduce(lambda d, key: d.get(key, default) if isinstance(d, dict) else default, keys.split('.'), dictionary)
 
@@ -29,15 +32,43 @@ def imagen(
     assert model_path.exists(), f'model not found at {full_model_path}'
     loaded = torch.load(str(model_path))
 
+    # get version
+
     version = safeget(loaded, 'version')
     print(f'loading Imagen from {full_model_path}, saved at version {version} - current package version is {__version__}')
 
-    init_params = safeget(loaded, 'init_params')
-    model_params = safeget(loaded, 'model_params')
+    # get imagen parameters and type
+
+    imagen_params = safeget(loaded, 'imagen_params')
+    imagen_type = safeget(loaded, 'imagen_type')
+
+    if imagen_type == 'original':
+        imagen_klass = ImagenConfig
+    elif imagen_type == 'elucidated':
+        imagen_klass = ElucidatedImagenConfig
+    else:
+        raise ValueError(f'unknown imagen type {imagen_type}')
+
+    assert exists(imagen_params) and exists(imagen_type), 'imagen type and configuration not saved in this checkpoint'
+
+    imagen = imagen_klass(**imagen_params).create()
+
+    imagen.cuda()
+
+    # get trained model parameters
+
+    model_params = safeget(loaded, 'model')
+
+    # load model parameters
 
-    imagen = Imagen(**init_params)
     imagen.load_state_dict(model_params)
 
-    pil_image = imagen(text, cond_scale = cond_scale, return_pil_images = True)
+    # generate image
 
-    return pil_image.save(f'./{simple_slugify(text)}.png')
+    pil_image = imagen.sample(text, cond_scale = cond_scale, return_pil_images = True)
+
+    image_path = f'./{simple_slugify(text)}.png'
+    pil_image[0].save(image_path)
+
+    print(f'image saved to {str(image_path)}')
+    return
